From: Johannes Schindelin Date: Thu, 11 Jan 2007 08:53:34 GMT Subject: Re: What's cooking in git.git (topics) Message-ID: In-Reply-To: <7v3b6i75i5.fsf@assigned-by-dhcp.cox.net> Hi, On Wed, 10 Jan 2007, Junio C Hamano wrote: > * ar/merge-recursive (Wed Jan 10 11:20:58 2007 -0800) 2 commits > + merge-recursive: do not use on-file index when not needed. > + Speed-up recursive by flushing index only once for all entries > > I did not see much improvement (maybe a largish kernel merge > going from 2.5 seconds to slightly less than one second) That is a heck of an improvement. It is only uses 40% of the time it used before! On other machines, with other OSes, this makes the difference between 10 minutes and 4 minutes. BTW I am not quite sure if you missed this patch: http://thread.gmane.org/gmane.comp.version-control.git/36212/, or if you did not like it, want enhancements, ... Ciao, Dscho